@@ -81,19 +81,19 @@ def main(argv):
         elif args.subparser == "test":
             _run_test()
         elif args.subparser in ["query", "q"]:
-            q = args.gene
+            q = args.query
             if "*" in q:
                 gene, q = q.split("*", maxsplit=1)
             else:
                 gene, q = q, ""
+            if args.gene:
+                gene = args.gene
             db_file = script_path("aldy.resources.genes/{}.yml".format(gene.lower()))
-            if os.path.exists(db_file):
-                gene_db = db_file
-            else:
-                gene_db = gene
-            with open(gene_db):  # Check if file exists
+            if not os.path.exists(db_file):
+                db_file = gene
+            with open(db_file):  # Check if file exists
                 pass
-            query(Gene(gene_db), q)
+            query(Gene(db_file), q)
         elif args.subparser == "profile":
             p = load_sam_profile(
                 args.file, cn_region=parse_cn_region(args.cn_neutral_region)
@@ -136,7 +136,7 @@ def main(argv):
         exit(ex.code)
     except Exception as ex:
         log.critical(
-            f"ERROR: gene= {args.gene}, profile= {args.profile}, file= {args.file}"
+            f"ERROR: gene= {args.gene}, file= {args.file if 'file' in args else '-'}"
         )
         log.critical(repr(ex))
         log.warn(traceback.format_exc())
@@ -144,7 +144,7 @@ def main(argv):
     except:  # noqa
         exc = sys.exc_info()[0]
         log.critical(
-            f"ERROR: gene= {args.gene}, profile= {args.profile}, file= {args.file}"
+            f"ERROR: gene= {args.gene}, file= {args.file if 'file' in args else '-'}"
         )
         log.critical("Unrecoverable error: {}", repr(exc))
         log.warn(traceback.format_exc())
@@ -305,6 +305,11 @@ def _get_args(argv):
         + "(also warn if there are multiple major solutions)."
         + "Default is 1 (warn after the genotyping).",
     )
+    genotype_parser.add_argument(
+        "--min-coverage",
+        default=None,
+        help=td("""Minimum mutation read coverage. Default is 1."""),
+    )
     genotype_parser.add_argument("--phase", help="Use phase file.")
 
     _ = subparsers.add_parser(
@@ -321,7 +326,8 @@ def _get_args(argv):
         parents=[base],
         help="Query database definitions for a given gene.",
     )
-    show_parser.add_argument("gene", help="Gene or allele to show.")
+    show_parser.add_argument("--gene", "-g", default=None, help="Gene file.")
+    show_parser.add_argument("query", help="Gene or allele to show.")
 
     profile_parser = subparsers.add_parser(
         "profile",
@@ -403,6 +409,7 @@ def _genotype(gene: str, output: Optional[Any], args) -> None:
                 multiple_warn_level=args.multiple_warn_level,
                 phase=args.phase,
                 report=True,
+                min_cov=args.min_coverage,
             )
         except AldyException as ex:
             log.critical(
