@@ -47,6 +47,7 @@ def genotype(
     phase: Optional[str] = None,
     report: bool = False,
     genome=None,
+    min_cov: Optional[str] = None,
 ) -> List[solutions.MinorSolution]:
     """
     Genotype a sample.
@@ -99,7 +100,9 @@ def genotype(
             Prefix for debug information and core dump files.
             ``None`` for no debug information.
             Default is ``None``.
-
+        min_cov (float):
+            Minimum mutation read coverage.
+            Default is 1.
     Raises:
         :obj:`aldy.common.AldyException` if the average coverage is too low (below 2).
     """
@@ -145,6 +148,8 @@ def genotype(
         cn_region = None
         cn_solution = ["1", "1"]
         profile = "illumina"
+        if not min_cov:
+            min_cov = "5.0"
     elif profile == "wgs":
         profile = "illumina"
     elif profile == "pgrnseq-v1":
@@ -168,15 +173,16 @@ def genotype(
             reference=reference,
             cn_region=None if cn_solution else cn_region,
             debug=debug,
+            min_cov=float(min_cov) if min_cov else 1.0,
         )
         avg_cov = sample.coverage.average_coverage()
-        if avg_cov < 2:
+        if cn_region and avg_cov < 2:
             raise AldyException(
                 f"Average coverage of {avg_cov:.2f} for gene {gene.name} is too low; "
                 + f"skipping gene {gene.name}. "
                 + f"Please ensure that {gene.name} is present in the input SAM/BAM."
             )
-        elif avg_cov < 20:
+        elif cn_region and avg_cov < 20:
             log.warn(
                 f"Average sample coverage is {avg_cov}. "
                 + "We recommend at least 20x coverage for the best results."
@@ -308,11 +314,6 @@ def genotype(
             diplotype.write_decomposition(
                 sample_name, gene, i + 1, minor_sol, output_file
             )
-        # print(
-        #     sample.coverage.sample,
-        #     gene.name,
-        #     minor_sol.get_major_diplotype().replace(" ", ""),
-        # )
     if is_vcf:
         diplotype.write_vcf(sample_name, gene, sample.coverage, minor_sols, output_file)
 
@@ -326,6 +327,17 @@ def genotype(
                 log.info(f"    Minor: {r.get_minor_diplotype()}")
                 log.info(f"    Legacy notation: {r.get_minor_diplotype(legacy=True)}")
                 reported.add(s)
+                # Calculate coverage of each mutation in a solution
+                for m, mc, sc in r.get_mutation_coverages(sample.coverage):
+                    if abs(mc - sc) > 0.5:
+                        log.warn(
+                            "    Warning: Coverage of {} is not in line with "
+                            "the prediction\n"
+                            "             (predicted: {:.1f}, observed: {:.1f})",
+                            gene.get_rsid(m),
+                            mc,
+                            sc,
+                        )
     if any(len(m.major_solution.added) > 0 for m in minor_sols) and not phase:
         novels = {
             gene.get_rsid(mm) for m in minor_sols for mm in m.major_solution.added
