@@ -5,12 +5,12 @@
 
 from typing import List, Set, Callable, Optional, Tuple, Dict
 
+from os import environ
 from natsort import natsorted
 from . import lpinterface
 from .common import log, json
 from .gene import Mutation, Gene
 from .cn import MAX_CN
-from .major import NOVEL_MUTATION_PENAL
 from .coverage import Coverage
 from .solutions import MajorSolution, SolvedAllele, MinorSolution
 from .diplotype import estimate_diplotype
@@ -74,9 +74,10 @@ def estimate_minor(
                 SolvedAllele(gene, sa.major, mi) for mi in gene.alleles[sa.major].minors
             ]
             mutations |= set(gene.alleles[sa.major].func_muts)
-            for sa in gene.alleles[sa.major].minors.values():
-                mutations |= set(sa.neutral_muts)
+            for minor in gene.alleles[sa.major].minors.values():
+                mutations |= set(minor.neutral_muts)
         mutations |= set(major_sol.added)
+    mutations |= gene.random_mutations
 
     # Filter out low quality mutations
     def default_filter_fn(mut, cov, total, thres):
@@ -89,8 +90,10 @@ def estimate_minor(
         ):
             return False
         return Coverage.basic_filter(
-            mut, cov, total, thres / MAX_CN
-        ) and Coverage.cn_filter(mut, cov, total, thres, major_sol.cn_solution)
+            mut, cov, total, thres / MAX_CN, coverage.min_cov
+        ) and Coverage.cn_filter(
+            mut, cov, total, thres, major_sol.cn_solution, coverage.min_cov
+        )
 
     if filter_fn:
         cov = coverage.filtered(filter_fn)
@@ -458,7 +461,7 @@ def solve_minor_model(
             model.addConstr(vo <= model.quicksum(vars))
             for v in vars:
                 model.addConstr(vo >= v)
-            objective += NOVEL_MUTATION_PENAL * vo
+            objective += ADD_PENALTY_FACTOR / 2 * vo
     PHASE_ERROR = 10
     objective += PHASE_ERROR * model.quicksum(VPHASEERR)
 
@@ -487,6 +490,16 @@ def solve_minor_model(
             for m, mv in VNEW[allele].items():
                 if model.getValue(mv[0]):
                     added.append(m)
+                else:
+                    copies = coverage.single_copy(m.pos, major_sol.cn_solution)
+                    copies = coverage[m] / copies if copies > 0 else 0
+                    if abs(copies - major_sol.cn_solution.max_cn()) > 1e-5:
+                        continue
+                    # HACK: add homozygous mutation to _all_ alleles
+                    # Works only if a mutation is unambiguiusly homozygous;
+                    # otherwise, it will fall back to the model defaults
+                    if m not in alleles[allele]:
+                        added.append(m)
             solution.append(
                 SolvedAllele(
                     gene,
@@ -512,7 +525,7 @@ def solve_minor_model(
     if not results:
         log.debug("[minor] solution= []")
         debug_info["sol"] = []
-        if debug and False:  # Enable to debug infeasible models
+        if debug and "ALDY_IIS" in environ:  # Enable to debug infeasible models
             model.model.computeIIS()
             model.dump(f"{debug}.iis.ilp")
     return sorted(results.values(), key=lambda x: str(x.get_minor_diplotype()))
