@@ -44,6 +44,7 @@ class Sample:
 
     coverage: Coverage
     sample_name: str
+    min_cov: float
     _prefix: str
     _insertion_sites: Set[Mutation]
     _insertion_counts: Dict[Tuple[int, int], int]
@@ -61,6 +62,7 @@ class Sample:
         cn_region: Optional[GRange] = None,
         debug: Optional[str] = None,
         vcf_path: Optional[str] = None,
+        min_cov: float = 1.0,
     ):
         """
         Initialize a :obj:`Sample` object.
@@ -91,6 +93,7 @@ class Sample:
         # Get the list of indel sites that should be corrected
         # TODO: currently uses only functional indels;
         #       other indels should be corrected as well
+        self.min_cov = min_cov
         self._dump = defaultdict(int), []
         self._insertion_sites = {
             m for a in gene.alleles.values() for m in a.func_muts if m.op[:3] == "ins"
@@ -394,7 +397,11 @@ class Sample:
             threshold,
             self._dump[0],
             self.sample_name,
+            self.min_cov,
         )
+        # for p in coverage:
+        # if len(coverage[p]) > 1:
+        # log.trace('{}: {}', p, {m: v for m,v in coverage[p].items() if v>1})
 
     def _group_indels(self, gene, coverage):
         # Group ambiguous deletions
@@ -743,6 +750,8 @@ def load_sam_profile(
 
     cov: dict = defaultdict(lambda: defaultdict(int))
     for c, (s, e) in natsorted(chr_regions.items()):
+        if sam_path == "<illumina>":
+            continue
         with pysam.AlignmentFile(sam_path) as sam:
             region = GRange(c, s, e).samtools(
                 pad_left=1000,
@@ -781,7 +790,10 @@ def load_sam_profile(
             d[g][r] = [0]
         if ri >= len(d[g][r]):
             d[g][r].append(0)
-        d[g][r][ri] = sum(cov[c][i] * (factor / 2.0) for i in range(s, e))
+        if sam_path == "<illumina>":
+            d[g][r][ri] = sum(1.0 for i in range(s, e))
+        else:
+            d[g][r][ri] = sum(cov[c][i] * (factor / 2.0) for i in range(s, e))
     return d
 
 
